import { ConventionalCommits } from './conventional-commits';
import { GitHub, GitHubTag, OctokitAPIs } from './github';
import { Commit } from './graphql-to-commits';
import { Update } from './updaters/update';
export declare enum ReleaseType {
    Node = "node",
    PHPYoshi = "php-yoshi",
    JavaAuthYoshi = "java-auth-yoshi",
    JavaYoshi = "java-yoshi",
    Python = "python",
    TerraformModule = "terraform-module",
    Ruby = "ruby",
    RubyYoshi = "ruby-yoshi"
}
export interface BuildOptions {
    bumpMinorPreMajor?: boolean;
    label?: string;
    token?: string;
    repoUrl: string;
    packageName: string;
    releaseAs?: string;
    apiUrl: string;
    proxyKey?: string;
    snapshot?: boolean;
    lastPackageVersion?: string;
    octokitAPIs?: OctokitAPIs;
}
export interface ReleasePROptions extends BuildOptions {
    releaseType: ReleaseType;
}
export interface ReleaseCandidate {
    version: string;
    previousTag?: string;
}
export declare class ReleasePR {
    apiUrl: string;
    labels: string[];
    gh: GitHub;
    bumpMinorPreMajor?: boolean;
    repoUrl: string;
    token: string | undefined;
    packageName: string;
    releaseAs?: string;
    proxyKey?: string;
    snapshot?: boolean;
    lastPackageVersion?: string;
    constructor(options: ReleasePROptions);
    run(): Promise<void>;
    protected _run(): Promise<void>;
    private closeStaleReleasePRs;
    protected defaultInitialVersion(): string;
    protected coerceReleaseCandidate(cc: ConventionalCommits, latestTag: GitHubTag | undefined): Promise<ReleaseCandidate>;
    protected commits(sha?: string, perPage?: number, labels?: boolean, path?: string | null): Promise<Commit[]>;
    protected gitHubInstance(octokitAPIs?: OctokitAPIs): GitHub;
    protected openPR(sha: string, changelogEntry: string, updates: Update[], version: string, includePackageName?: boolean): Promise<void>;
    protected changelogEmpty(changelogEntry: string): boolean;
}
